Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(158)

Unified Diff: components/data_reduction_proxy/core/browser/data_reduction_proxy_config.h

Issue 2642793005: Create a Lite Page bit for previews and fallback to Lo-Fi (Closed)
Patch Set: remove unused frame_messages.h code Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/data_reduction_proxy/core/browser/data_reduction_proxy_config.h
diff --git a/components/data_reduction_proxy/core/browser/data_reduction_proxy_config.h b/components/data_reduction_proxy/core/browser/data_reduction_proxy_config.h
index c768ea3bb9ff6a68334c8688c0c9ca7ce014a928..3434816604704f457323178e0599d8e8013b6276 100644
--- a/components/data_reduction_proxy/core/browser/data_reduction_proxy_config.h
+++ b/components/data_reduction_proxy/core/browser/data_reduction_proxy_config.h
@@ -191,10 +191,14 @@ class DataReductionProxyConfig
// Returns |lofi_off_|.
bool lofi_off() const { return lofi_off_; }
- // Returns true when Lo-Fi mode should be activated. Records metrics for Lo-Fi
- // state changes. |request| is used to get the network quality estimator from
- // the URLRequestContext.
- bool ShouldEnableLoFiMode(const net::URLRequest& request);
+ // Returns true when Lo-Fi Previews should be activated. Records metrics for
+ // Lo-Fi state changes. |request| is used to get the network quality estimator
+ // from the URLRequestContext.
+ bool ShouldEnableLoFi(const net::URLRequest& request);
+
+ // Returns true when Lite Page Previews should be activated. |request| is used
+ // to get the network quality estimator from the URLRequestContext.
+ bool ShouldEnableLitePages(const net::URLRequest& request);
// Returns true if the data saver has been enabled by the user, and the data
// saver proxy is reachable.
@@ -291,10 +295,17 @@ class DataReductionProxyConfig
bool is_https,
base::TimeDelta* min_retry_delay) const;
- // Returns true when Lo-Fi mode should be activated. Determines if Lo-Fi mode
- // should be activated by checking the Lo-Fi flags and if the network quality
- // is prohibitively slow. |network_quality_estimator| may be NULL.
- bool ShouldEnableLoFiModeInternal(
+ // Returns true when Lo-Fi Previews should be activated. Determines if Lo-Fi
+ // Previews should be activated by checking the Lo-Fi flags and if the network
+ // quality is prohibitively slow. |network_quality_estimator| may be NULL.
+ bool ShouldEnableLoFiInternal(
+ const net::NetworkQualityEstimator* network_quality_estimator);
+
+ // Returns true when Lite Page Previews should be activated. Determines if
+ // Lite Page Previewsmode should be activated by checking the Lite Page
+ // Previews flags and if the network quality is prohibitively slow.
+ // |network_quality_estimator| may be NULL.
+ bool ShouldEnableLitePagesInternal(
const net::NetworkQualityEstimator* network_quality_estimator);
// Returns true if the network quality is at least as poor as the one

Powered by Google App Engine
This is Rietveld 408576698